==> haskell-status-notifier-item-0.3.1.0-276-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-Dq3niBbSGiu5xF06dUNExO
key:                  status-notifier-item-0.3.1.0-Dq3niBbSGiu5xF06dUNExO
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  cd69953b5123f7a0dae5c6ad82aa959c
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-Dq3niBbSGiu5xF06dUNExO
depends:
    base-4.17.2.1 byte-order-0.1.3.1-KGz8BLOIfqV2gIe7jqAceC
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-1GxZY8w0fEwJzxny37QSSC
    containers-0.6.7 dbus-1.3.3-9oZX57MILji9wPzPmV4ul filepath-1.4.2.2
    hslogger-1.3.2.0-GIpThsGwCfb89D3W3gYH5u
    lens-5.3.1-Hr3CNVd7aJGEq0oCRlwS0q template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    vector-0.13.2.0-PKWel9ZBueBULxf3GbwPA

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-status-notifier-item-0.3.1.0-277-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-3Yx98HhhRdKJ4xQ9EfFIIB
key:                  status-notifier-item-0.3.1.0-3Yx98HhhRdKJ4xQ9EfFIIB
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  49855d046de04899a162e1d8d58096a4
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-3Yx98HhhRdKJ4xQ9EfFIIB
depends:
    base-4.17.2.1 byte-order-0.1.3.1-6bFEncSN52wBSU0bUtsDzP
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-2PeIM4w2KtCgjylGw40Sx containers-0.6.7
    dbus-1.3.3-9ERQEtA0JwPIEdpbbXMq8L filepath-1.4.2.2
    hslogger-1.3.2.0-AzvyJp6KC686sMbxwPnIts
    lens-5.3.1-DW98VpYgL8e3Qofq450fQJ template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    vector-0.13.2.0-6oLw41loWTIuQEg8iaHmr

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
